// Copyright 2022 Jens W. Wulf, originally published at http://www.jwwulf.de/en/kbd/
// This file licensed under the
// Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
// To view a copy of this license, visit
// https://creativecommons.org/licenses/by-nc-sa/4.0/

// Print settings:
// 15% Gyroid Infill, unten nur ein Layer, zwei Perimeter
include <jw_rect_round.scad>

// (un)comment the mirror-statement in line 81 for left/right part.

// Abstand des Wellenmittelpunkts zur Ecke
dr=6;

// Rand in y-Richtung, also die Dicke des Materials bei den Löchern
ry=6;

// Durchmesser der Welle
dw=6+0.5; 

// mehr Platz um die Welle herum
dh=dw+2*3;

// Ausgaben der Grid-Erzeugung:
grid_dist_x=0.993421052631579;
grid_dist_y=1.005741980767742;
dx=75.5;
dy=62.3560028076;
// Und Berechnungen damit:
scaley = dy / (grid_dist_y * (dy/grid_dist_y - 1)) * grid_dist_y;
scalex = dx / (grid_dist_x * (dx/grid_dist_x - 1)) * grid_dist_x;
ly=dy;

// Grundplatte 62mm x 75mm
// Abstand der Bohrungen für die Halterungen: ly-2*ry-4,
// Abstand von Außenkante ry+2

 
module fast_alles() {
  difference(){
    translate([0,0,22])
      rotate([0,25,0])
        intersection(){
          union(){ 
            translate([dx,dy,18]) rotate([0,0,180]) scale([scalex, scaley, 1]) surface(file="ablage_rechts_2.grid");
            translate([0,0,-100-8]) cube([dx,dy,100],center=false);
          }
          translate([0,0,-50]) jw_rect_round(dx, dy, 100, 3, 20, center=false);
        }
    translate([0,0,-100]) cube([200,200,200],center=true);
    translate([-200,-1,-1]) cube([200,200,200],center=false);
    
    // durchgehendes Loch für die Welle
    translate([dr,0,dr]) rotate([90,0,0]) cylinder(d=dw, h=200, $fn=30, center=true);
   
    // innere Aussparung um die Welle, muss zwingende vorhanden sein
    translate([dr,ry,dr]) rotate([-90,0,0]) cylinder(d=dh, h=ly-2*ry, $fn=60, center=false);
  
    // vergrößert die innere Aussparung, damit es leichter zu drucken ist
    translate([dh/2/sqrt(2)+dr,ry+4,dh/2/sqrt(2)+dr]) rotate([0,-130,0]) cube([3*dh, ly-2*ry-4, 3*dh],center=false);
    
    // vergrößert die innere Aussparung, damit es leichter zu drucken ist
    translate([-0.01,ry,0]) cube([dr, ly-2*ry, dr+dh/2],center=false);
    translate([0,ry,-0.01]) cube([dr+dh/2, ly-2*ry, dr],center=false);
    
    
    // Rundung um Drehachse
    translate([-0.01,-1,-0.01]) difference(){
      cube([dr,100,dr],center=false);
      translate([dr,0,dr]) rotate([90,0,0]) cylinder(d=2*dr, h=200, $fn=30, center=true);
    } 
  
    // unnötigen Überstand schneiden
    translate([0,20,20]) rotate([0,30,0]) rotate([0,0,-7]) translate([-20,0,0]) cube([40,200,100], center=true);
  }
}


// (un)comment the following line for left/right part:
//mirror([1,0,0])
  difference() {
    fast_alles();
    translate([-7,0,-4]) intersection() {
      fast_alles();
      translate([0,ry+4,0]) cube([19.2, ly-2*ry-4, 200],center=false);  
    }
  }
  
  



